@@ -1,4 +1,4 @@
-"stan" <-
+stan <-
 structure(list(time = c(15, 3, 46, 623, 126, 64, 1350, 23, 279, 
 1024, 10, 39, 730, 1961, 136, 1, 836, 60, 3695, 1996, 0, 47, 
 54, 51, 2878, 3410, 44, 994, 51, 1478, 254, 897, 148, 51, 323, 
@@ -57,7 +57,7 @@ structure(list(time = c(15, 3, 46, 623, 126, 64, 1350, 23, 279,
 41.4969878424929, 30.4630924234556, 41.4487635521254, 4.69041575982343, 
 6.32455532033676, 2.64575131106459, 40.4722126896961, 40.1497197997695, 
 5, 39.1663120551323, 39.3319208785943, 35.6510869399518, 6.6332495807108, 
-35.3128871660192, 35.0998575495685, 13.8202749610853, 37.3229152130430, 
+35.3128871660192, 35.0998575495685, 13.8202749610853, 37.322915213043, 
 34.6698716467194, 37.1214223865412, 37.0540146272978, 16.5529453572468, 
 5.56776436283002, 36.6196668472011, 6.48074069840786, 19.5192212959431, 
 35.5527776692624, 35.5246393366632, 35.5105618091294, 6.85565460040104, 
@@ -69,7 +69,7 @@ structure(list(time = c(15, 3, 46, 623, 126, 64, 1350, 23, 279,
 27.4226184016042, 27.1661554144122, 9.2736184954957, 11.4891252930761, 
 25.7487863791675, 25.6904651573303, 14.8660687473185, 9.48683298050514, 
 24.8797106092495, 24.8596057893121, 24, 23.7276210354093, 6, 
-23.4307490277200, 23.4093998214393, 23.259406699226, 23.1084400165827, 
+23.43074902772, 23.4093998214393, 23.259406699226, 23.1084400165827, 
 13, 11.0453610171873, 19.5448202856921, 21.6333076527839, 21.540659228538, 
 3.16227766016838, 2.23606797749979, 11.6619037896906, 20.1494416796099, 
 19.7737199332852, 19.3390796058137, 7.07106781186548, 11.7898261225516, 
@@ -77,23 +77,5 @@ structure(list(time = c(15, 3, 46, 623, 126, 64, 1350, 23, 279,
 15.1986841535707, 12.0415945787923, 13.7113092008021, 13.2664991614216, 
 11.7473401244707, 12.2065556157337, 10.9087121146357, 10.3440804327886, 
 9.89949493661167, 9.4339811320566, 7.74596669241483, 7.48331477354788, 
-1.41421356237310, 1)), .Names = c("time", "status", "age", "futime"
-), row.names = c("1", "2", "3", "4", "5", "6", "7", "8", "9", 
-"10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", 
-"21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31", 
-"32", "33", "34", "35", "36", "37", "38", "39", "40", "41", "42", 
-"43", "44", "45", "46", "47", "48", "49", "50", "51", "52", "53", 
-"54", "55", "56", "57", "58", "59", "60", "61", "62", "63", "64", 
-"65", "66", "67", "68", "69", "70", "71", "72", "73", "74", "75", 
-"76", "77", "78", "79", "80", "81", "82", "83", "84", "85", "86", 
-"87", "88", "89", "90", "91", "92", "93", "94", "95", "96", "97", 
-"98", "99", "100", "101", "102", "103", "104", "105", "106", 
-"107", "108", "109", "110", "111", "112", "113", "114", "115", 
-"116", "117", "118", "119", "120", "121", "122", "123", "124", 
-"125", "126", "127", "128", "129", "130", "131", "132", "133", 
-"134", "135", "136", "137", "138", "139", "140", "141", "142", 
-"143", "144", "145", "146", "147", "148", "149", "150", "151", 
-"152", "153", "154", "155", "156", "157", "158", "159", "160", 
-"161", "162", "163", "164", "165", "166", "167", "168", "169", 
-"170", "171", "172", "173", "174", "175", "176", "177", "178", 
-"179", "180", "181", "182", "183", "184"), class = "data.frame")
+1.4142135623731, 1)), .Names = c("time", "status", "age", "futime"
+), row.names = c(NA, 184L), class = "data.frame")
